import { SagaIterator } from 'redux-saga';
import { call, Effect, fork, put, takeEvery } from 'redux-saga/effects';

import Action from '@overflow/commons/redux/Action';
import SagaWatcher from '@overflow/commons/redux/saga/SagaWatcher';
import * as AsyncRequestActions  from '@overflow/commons/redux/action/asyncRequest';
import AsyncRequestPayload from '@overflow/commons/redux/payload/AsyncRequestPayload';

import WebSocketRPC from '@overflow/commons/websocket/WebSocketRPC';

import * as AppAsyncRequestSendingActions  from '../action/asyncRequestSending';

export class AsyncRequest implements SagaWatcher {
  private _webSocketRPC: WebSocketRPC;

  public setWebSocketRPC(webSocketRPC: WebSocketRPC): void {
    this._webSocketRPC = webSocketRPC;
  }

  private * request(webSocketRPC: WebSocketRPC, action: Action<AsyncRequestPayload>): SagaIterator {
    const {service, method, requestType, args} = action.payload;
    try {
      yield put(AppAsyncRequestSendingActions.sending(false));

      let result = yield call({context: webSocketRPC, fn: webSocketRPC.Call}, `${service}.${method}`, args);

      yield put(AsyncRequestActions.requestSuccess(requestType, result));
    } catch (e) {
      yield put(AsyncRequestActions.requestFailure(requestType, e));
    } finally {
      yield put(AppAsyncRequestSendingActions.sending(true));
    }
  }

  public * watch(): SagaIterator {
    yield takeEvery(AsyncRequestActions.REQUEST, this.request, this._webSocketRPC);
  }

}

export default AsyncRequest;
