import * as React from 'react';
import { RouteComponentProps, RouteProps, Route, Switch } from 'react-router-dom';
import { Container, Segment } from 'semantic-ui-react';
import { Header } from './Header';
import { Footer } from './Footer';
import LeftMenu from './LeftMenu';

import TableSortView from '../../../temp/react/components/TableSortView';
import DiscoveryTreeContainer from '@overflow/discovery/react/DiscoveryTree';
import HistoryListContainer from '@overflow/history/react/HistoryList';

export interface Props extends RouteComponentProps<any> {
}
export interface State {
  sidebar_visible: boolean;
  notification_visible: boolean;
}

export class AppLayout extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      sidebar_visible: true,
      notification_visible: false,
    };
  }

  public onSidebar = () => {
    this.setState({ notification_visible: !this.state.notification_visible, sidebar_visible: !this.state.sidebar_visible });
  }

  public render(): JSX.Element {
    return (
      <Switch>
        <Container fluid>
          <LeftMenu />
          <Segment basic style={{ margin: '0 0 0 210px', padding: '0' }}>
            <Header />
            <Route exact path={`${this.props.match.url}/tablesort`} component={TableSortView} />
            <Route exact path={`${this.props.match.url}/discoveryTree`} component={DiscoveryTreeContainer} />
            <Route exact path={`${this.props.match.url}/historyList`} component={HistoryListContainer} />
            <Footer />
          </Segment>
        </Container >
      </Switch>
    );
  }
}

export default AppLayout;

