import * as React from 'react';
import { Grid, Container, Breadcrumb, Header, Menu, Input, Segment, Dropdown } from 'semantic-ui-react';


export interface StateProps {
  sub: any;
  location: string;
}

export interface DispatchProps {
  onRedirect(path: string): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: number;
}

export class TitleBar extends React.Component<Props, State> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      selected: 0,
    };
  }

  public handleMenu(menu: any, index: number): any {
    this.setState({
      selected: index,
    });
    if (this.state.selected !== index) {
      this.props.onRedirect(menu.path);
    }
  }

  public renderSubMenus(): JSX.Element {
    let subMenus = this.props.sub;
    if (!subMenus) {
      return null;
    }

    return subMenus.map((menu: any, index: number) => (
      <Menu.Item key={index} name={menu.name} onClick={this.handleMenu.bind(this, menu, index)} active={this.state.selected === index} />
    ));
  }

  public showTitle(): string {
    let elems: JSX.Element[] = new Array();
    let pathArr = this.props.location.split('/');
    let title = pathArr[1].replace(/_/g, ' ');
    return title.toUpperCase();
  }

  public handleBreadcrumb = (path: string) => {
    console.log(path);
    this.props.onRedirect(path);
  }

  // temporary
  public renderBreadcrumb(): JSX.Element[] {

    let options = [
      {
        text: 'Probes',
        value: 'probes',
      },
      {
        text: 'Targets',
        value: 'targets',
      },
      {
        text: 'Sensors',
        value: 'sensors',
      },
    ];

    let elems: JSX.Element[] = new Array();
    let pathArr = this.props.location.split('/');
    let index: number = 0;

    for (let item of pathArr) {
      if (item !== '' && !item.match(/^\d+$/)) {
        let path = '/' + item;
        elems.push(
          <Breadcrumb.Section key={index++} onClick={this.handleBreadcrumb.bind(this, path)}>
            {this.capitalizeFirst(item)}
             {/* <Dropdown inline options={options} defaultValue={this.capitalizeFirst(item)}/> */}
          </Breadcrumb.Section>);
        elems.push(<Breadcrumb.Divider key={index++} />);
      }
    }
    return elems;
  }

  public render(): JSX.Element {
    return (
      <Menu fluid style={{ borderLeft: '0px', borderRight: '0px', boxShadow: 'none', borderRadius: '0', marginTop:'0'}} pointing>
        <Menu.Item style={{ width: '250px' }} >
          <Header as='h3'>{this.showTitle()}
            <Header.Subheader>
              <Breadcrumb size='mini'>
                <Breadcrumb.Section onClick={this.handleBreadcrumb.bind(this, '/')}>Home</Breadcrumb.Section>
                <Breadcrumb.Divider />
                {this.renderBreadcrumb()}
              </Breadcrumb>
            </Header.Subheader>
          </Header>
        </Menu.Item>
        {this.renderSubMenus()}
      </Menu>
    );
  }
  private capitalizeFirst(str: string): string {
    return str.charAt(0).toUpperCase() + str.slice(1);
  }
}



