export const enum ErrorCode {
  E_RUNTIME = -33000,
  E_PARSE = -32700,
  E_INVALID_REQ = -32600,
  E_NO_METHOD = -32601,
  E_BAD_PARAMS = -32602,
  E_INTERNAL = -32603,
  E_SERVER = -32000,

}

export class ProtocolError {
  private code: ErrorCode;
  private message: string;
  private data: any;

  public constructor(code: ErrorCode, message: string, data: any) {
    this.code = code;
    this.message = message;
    this.data = data;
  }

  /**
   * getID
   */
  public get Code(): ErrorCode {
    return this.code;
  }

  /**
   * getBody
   */
  public get Message(): string {
    return this.message;
  }

  /**
   * getError
   */
  public get Data(): any {
    return this.data;
  }

  public static convert(error: ProtocolError): ProtocolError {
    if (undefined === error) {
      return undefined;
    }
    const code = error.code;
    if (undefined === code) {
      throw new Error(`Error must include Code`);
    }
    return new ProtocolError(code, error.message, error.data);
  }
}

export default ProtocolError;
