import Header from './Header';
import ProtocolError from './ProtocolError';

export class Response<ID> extends Header {
  protected id: ID;
  private result: any;
  protected error: ProtocolError;

  public constructor(id: ID) {
    super();
    if (undefined === id) {
      throw new Error(`Response must include ID`);
    }
    this.id = id;
  }

  /**
   * get ID
   */
  public get ID(): ID {
    return this.id;
  }

  /**
   * get Result
   */
  public get Result(): any {
    return this.result;
  }

  /**
   * get Error
   */
  public get Error(): ProtocolError {
    return this.error;
  }

  public static convert<T>(response: Response<T>): Response<T> {
    const id = response.id;
    if (undefined === id) {
      throw new Error(`Response must include ID`);
    }
    let res = new Response(id);
    res.Protocol = response.protocol;
    res.result = response.result;
    if (undefined !== response.error) {
      res.error = ProtocolError.convert(response.error);
    }
    return res;
  }

}

export default Response;
