import * as React from 'react';
import {
  Button,
  Modal,
  Checkbox,
  Header,
  Container,
} from 'semantic-ui-react';
import { DiscoveryProbe } from './DiscoveryProbe';
import DiscoveryTableContainer from '../DiscoveryTable';
import DiscoveryTreeContainer from '../DiscoveryTree';

import Probe from '@overflow/probe/api/model/Probe';
import Host from '@overflow/discovery/api/model/Host';

export interface StateProps {
  probeId?: Number;
  open?: boolean;
  isSuccess?: boolean;
  onClosePopup?(bool: boolean): void;
  onRefreshList?(): void;
}

export interface DispatchProps {
  onCreateTarget?(hosts: Host[], probe: Probe): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  startPopup: boolean;
  // probeTemp: any;
}


export class Discovery extends React.Component<Props, State> {

  private submitData: any;
  private discoveryHosts: Array<Host>;

  public constructor(props: Props, context: State) {
    super(props, context);
    this.handleProbeChange.bind(this);
    this.state = {
      startPopup: false,
    };
  }

  public componentWillMount(): void {
    // this.setState({probeTemp:probeTemp});
  }

  public componentWillReceiveProps?(nextProps: Readonly<Props>, nextContext: any): void {
    if (this.props.isSuccess === undefined || this.props.isSuccess === false) {
      if (nextProps.isSuccess === true) {
        // this.props.onClosePopup(false);
        this.props.onRefreshList();
      }
    }

  }

  public handleProbeChange(obj: Object): void {
    console.log(obj);
    this.setState({ startPopup: true });
    // this.submitData = obj;
  }

  public handleSubmit(): void {
    // console.log(this.discoveryHosts);
    this.setState({startPopup:false});
    this.props.onCreateTarget(this.discoveryHosts, { id: Number(this.props.probeId) });
  }

  public onSetTargetList = (discoveryHosts: Array<Host>) => {
    this.discoveryHosts = discoveryHosts;
  }

  public handleCancel = () => this.setState({ startPopup: false });

  public handlePopupClose = () => this.setState({ startPopup: false });

  public render(): JSX.Element {
    return (
      <Modal
        open={this.props.open}
      >
        <Modal.Content>
          <Container fluid>
            <Header as='h3' dividing> Discovery Details</Header>
            <br />
            <DiscoveryTableContainer onProbeChange={this.handleProbeChange.bind(this)} />

            <Modal size='small' open={this.state.startPopup} onClose={this.handlePopupClose}>
              <Modal.Header>Discovery</Modal.Header>
              <Modal.Content >
                <DiscoveryTreeContainer probeId={this.props.probeId} onSetTargetList={this.onSetTargetList.bind(this)} />
              </Modal.Content>
              <Modal.Actions>
                <Button onClick={this.handleCancel}>              Cancel      </Button>
                <Button onClick={this.handleSubmit.bind(this)} primary>              Submit      </Button>
              </Modal.Actions>
            </Modal>

          </Container>
        </Modal.Content>
        <Modal.Actions>
          <Button onClick={() => this.props.onClosePopup(false)}>Cancel</Button>
          <Button primary >Done</Button>
        </Modal.Actions>
      </Modal>


    );
  }
}
