import * as React from 'react';
import {
  Table,
  Button,
  Input,
  InputProps,
  ButtonProps,
  Dropdown,
  Container,
  Header,
  DropdownProps,
} from 'semantic-ui-react';

import * as _ from 'lodash';

import DiscoveryStartInfo from '../../api/model/DiscoveryStartInfo';

export interface StateProps {
}

export interface DispatchProps {
  onProbeChange?(state: object): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  startIp: string;
  endIP: string;
  excludeIp: string;
  startPort: string;
  endPort: string;
}

export class DiscoveryTable extends React.Component<Props, State> {

  private serviceTemp: any;
  private selectedServices: number | string | Array<number | string>;

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      startIp: null,
      endIP: null,
      excludeIp: null,
      startPort: null,
      endPort: null,
    };
  }

  public componentWillMount(): void {
    // super.componentWillMount();
    this.serviceTemp = [
      { key: 'http', text: 'HTTP', value: 'http' },
      { key: 'ftp', text: 'FTP', value: 'ftp' },
      { key: 'snmp', text: 'SNMP', value: 'snmp' },
      { key: 'oracle', text: 'Oracle', value: 'oracle' },
      { key: 'mysql', text: 'MySQL', value: 'mysql' },
      { key: 'wmi', text: 'WMI', value: 'wmi' },
      { key: 'sql_server', text: 'SQL Server', value: 'sql_server' },
      { key: 'stmp', text: 'STMP', value: 'stmp' },
      { key: 'imap', text: 'IMAP', value: 'imap' },
      { key: 'ssh', text: 'SSH', value: 'ssh' },
      { key: 'telnet', text: 'Telnet', value: 'telnet' },
      { key: 'casandra', text: 'Casandra', value: 'casandra' },
      { key: 'mongodb', text: 'mongoDB', value: 'mongodb' },
      { key: 'rmi', text: 'RMI', value: 'rmi' },
    ];
  }

  public handleInput(event: React.SyntheticEvent<HTMLInputElement>, data: InputProps): void {
    // console.log( data.value);
    // console.log( event.target);
    // console.log(data.tabIndex);

    let value: string = data.value;
    switch (data.tabIndex) {
      case '1': {
        this.setState({
          startIp: value,
        });
        break;
      }
      case '2': {
        this.setState({
          endIP: value,
        });
        break;
      }
      case '3': {
        this.setState({
          excludeIp: value,
        });
        break;
      }
      case '4': {
        this.setState({
          startPort: value,
        });
        break;
      }
      case '5': {
        this.setState({
          endPort: value,
        });
        break;
      }
      default: {
        console.log('Error');
        break;
      }
    }

    console.log(this.state.startPort);
  }

  public discoveryStartHandler(event: React.SyntheticEvent<HTMLButtonElement>, data: ButtonProps): void {
    // Array<number | string>
    let convert: any = this.selectedServices;
    let discoveryStartInfo: DiscoveryStartInfo = {
      ...this.state,
      services: convert,
    };


    this.props.onProbeChange(discoveryStartInfo);
  }

  public render(): JSX.Element {
    return (
      <Container fluid>
        <Header as='h4' color='grey'> Discovery</Header>
        <Table>
          <Table.Body>
            <Table.Row>
              <Table.Cell width={4}><Header size='small'>Zone CIDR</Header></Table.Cell>
              <Table.Cell width={12}><Input fluid disabled placeholder='Start IP' defaultValue='192.168.1.0/24' /></Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell><Header size='small'>IP Range</Header></Table.Cell>
              <Table.Cell>
                <Input tabIndex='1' placeholder='Start IP' onChange={this.handleInput.bind(this)} /> &nbsp;&nbsp;
                <Input tabIndex='2' placeholder='End IP' onChange={this.handleInput.bind(this)} /> &nbsp;&nbsp;
                <Input tabIndex='3' placeholder='Exclude IP' onChange={this.handleInput.bind(this)} />
              </Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell><Header size='small'>Port Range</Header></Table.Cell>
              <Table.Cell>
                <Input tabIndex='4' placeholder='Start Port' onChange={this.handleInput.bind(this)} /> &nbsp;&nbsp;
                <Input tabIndex='5' placeholder='End Port' onChange={this.handleInput.bind(this)} />
              </Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell><Header size='small'>Service</Header></Table.Cell>
              <Table.Cell>
                <Dropdown placeholder='Service' fluid multiple selection options={this.serviceTemp}
                  onChange={(event: React.SyntheticEvent<HTMLElement>, data: DropdownProps) => {
                    this.selectedServices = data.value;
                  }} />
              </Table.Cell>
            </Table.Row>
          </Table.Body>
          <Table.Footer>
            <Table.Row>
              <Table.HeaderCell colSpan='2'>
                <Button icon='checkmark' floated='right' labelPosition='left'
                  content='Start' positive onClick={this.discoveryStartHandler.bind(this)} />
              </Table.HeaderCell>
            </Table.Row>
          </Table.Footer>
        </Table>
      </Container>
    );
  }
}
