
import * as React from 'react';
// import update from 'immutability-helper';
import * as _ from 'lodash';

import {
  Checkbox,
  Container,
  Label,
  Accordion,
  Icon, Header,
  List, Button,
  ListItemProps,
  CheckboxProps,
} from 'semantic-ui-react';


import Host from '@overflow/discovery/api/model/Host';
import Port from '@overflow/discovery/api/model/Port';
import Service from '@overflow/discovery/api/model/Service';
import Probe from '@overflow/probe/api/model/Probe';

import * as Utils from '@overflow/commons/util/Utils';


export interface DiscoveryTreeStateProps {
  probeId: number;
  onSetTargetList(discoveryHosts: Array<Host>): void;
}

export interface DiscoveryTreeDispatchProps {

}

export type DiscoveryTreeProps = DiscoveryTreeStateProps & DiscoveryTreeDispatchProps;

export interface DiscoveryTreeState {
  portState: Map<string, boolean>;
  serviceState: Map<string, boolean>;
  checkHostState: Map<string, boolean>;
  checkPortState: Map<string, boolean>;
  checkServiceState: Map<string, boolean>;

}


export class DiscoveryTree extends React.Component<DiscoveryTreeProps, DiscoveryTreeState> {

  private selectedHostState: Map<string, boolean>;
  private selectedPortState: Map<string, boolean>;
  private selectedServiceState: Map<string, boolean>;
  private discoveryHosts: Array<Host>;

  constructor(props: any, context: any) {
    super(props, context);

    this.state = {
      portState: new Map,
      serviceState: new Map,
      checkHostState: new Map,
      checkPortState: new Map,
      checkServiceState: new Map,
    };

    this.selectedHostState = new Map;
    this.selectedPortState = new Map;
    this.selectedServiceState = new Map;
    this.discoveryHosts = hostListJson;
    // fs.readFile('../../../../../dh.json', this.handlJSONFile);
  }

  public onClickHost = (key: string) => {
    let newPortStateMap: Map<string, boolean> = _.clone(this.state.portState);
    newPortStateMap[key] = !newPortStateMap[key];
    this.setState({ portState: newPortStateMap });
  }

  public onClickPort = (key: string) => {
    let newServiceStateMap: Map<string, boolean> = _.clone(this.state.serviceState);
    newServiceStateMap[key] = !newServiceStateMap[key];
    this.setState({ serviceState: newServiceStateMap });
  }

  public onCheck = (checkProps: CheckboxProps, checkState: Map<string, boolean>, key: string, stateKey: string,
                    selectedMap: Map<string, any>, selectedObj: Host | Port | Service) => {
    let newCheckState = _.clone(checkState);
    newCheckState[key] = !newCheckState[key];
    let state: any = {};
    state[stateKey] = newCheckState;
    this.setState(state);

    // if (checkProps.checked) {
    //   selectedMap[key] = selectedObj;
    // } else {
    //   delete selectedMap[key];
    // }
    if (stateKey !== 'checkPortState') {
      let checkObj: any = selectedObj;
      checkObj.target = checkProps.checked;
    }
    this.props.onSetTargetList(this.discoveryHosts);
    // if(selectedObj instanceof Host) {
    //   console.log(selectedObj);
    // }
  }

  public renderDiscovery(): JSX.Element[] {

    let elems: JSX.Element[] = new Array();

    let hostList: Host[] = this.discoveryHosts;
    let host: Host;
    for (let index: number = 0; index < hostList.length; ++index) {
      host = hostList[index];
      let key: string = String(host.ip);
      elems.push(
        <List.Item key={key} >
          <List.Icon name={host.ports ? (this.state.portState[key] ? 'chevron up' : 'chevron down') : 'file'}
            onClick={this.onClickHost.bind(this, key)} />
          <List.Content>
            <List.Header>
              <Checkbox label={Utils.int2ip(host.ip) + ' ' + host.os} checked={this.state.checkHostState[key]} onChange={
                (event: React.FormEvent<HTMLInputElement>, checkProps: CheckboxProps) => {
                  {
                    this.onCheck(checkProps, this.state.checkHostState, key, 'checkHostState', this.selectedHostState, host);
                  }
                }} />
            </List.Header>
            <List.Description style={{ marginLeft: '26px' }}>Host</List.Description>
            {host.ports ? (this.state.portState[key] ? this.renderPort(host.ports, key) : null) : null}
          </List.Content>
        </List.Item>,
      );
    }
    return elems;
  }

  public renderPort(portList: Port[], hostKey: string): JSX.Element[] {

    if (portList === undefined) {
      return null;
    }

    let elems: JSX.Element[] = new Array();
    let port: Port;
    for (let index: number = 0; index < portList.length; ++index) {
      port = portList[index];
      let key: string = hostKey + '-' + String(port.portNumber);
      elems.push(
        <List.List key={key}>
          <List.Item >
            <List.Icon name={port.services ? (this.state.serviceState[key] ? 'chevron up' : 'chevron down') : 'file'}
              onClick={this.onClickPort.bind(this, key)} />
            <List.Content>
              <List.Header> <Checkbox label={port.portNumber + ' ' + port.portType} checked={this.state.checkHostState[key]} onChange={
                (event: React.FormEvent<HTMLInputElement>, checkProps: CheckboxProps) => {
                  {
                    this.onCheck(checkProps, this.state.checkPortState, key, 'checkPortState', this.selectedPortState, port);
                  }
                }} /></List.Header>
              <List.Description style={{ marginLeft: '26px' }}>Port</List.Description>
              {port.services ? (this.state.serviceState[key] ? this.renderService(port.services, key) : null) : null}
            </List.Content>
          </List.Item>
        </List.List>,
      );
    }

    return elems;
  }

  public renderService(serviceList: Service[], portKey: string): JSX.Element[] {
    let elems: JSX.Element[] = new Array();
    let service: Service;
    for (let index: number = 0; index < serviceList.length; ++index) {
      service = serviceList[index];
      let key: string = portKey + '-' + service.serviceName;
      elems.push(
        <List.List key={key}>
          <List.Item >
            <List.Icon name='file' />
            <List.Content>
              <List.Header> <Checkbox label={service.serviceName + ' ' + service.portType}
                checked={this.state.checkHostState[key]} onChange={
                  (event: React.FormEvent<HTMLInputElement>, checkProps: CheckboxProps) => {
                    {
                      this.onCheck(checkProps, this.state.checkServiceState, key, 'checkServiceState', this.selectedServiceState, service);
                    }
                  }} /></List.Header>
              <List.Description style={{ marginLeft: '26px' }}>Service</List.Description>
            </List.Content>
          </List.Item>
        </List.List>,
      );
    }

    return elems;
  }

  public render(): JSX.Element {

    return (
      <Container fluid>
        {/*<Header as='h3' dividing> Discovery Result</Header>*/}
        <List selection>
          {this.renderDiscovery()}
        </List>
      </Container>
    );
  }

  private getHostKey(host: Host): string {
    return String(host.ip);
  }
  private getPortKey(host: Host, port: Port): string {
    return String(host.ip) + '-' + String(port.portNumber);
  }
  private GetServiceKey(host: Host, port: Port, service: Service): string {
    return String(host.ip) + '-' + String(port.portNumber) + '-' + service.serviceName;
  }

}



const hostListJson: any = [
  {
    'firstScanRange': 1,
    'lastScanRange': 10000,
    'name': '',
    'ip': 3232235818,
    'mac': 91754662925,
    'os': 'Windows',
    'ports': [{
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'services': [{
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'portType': 'TCP',
        'serviceName': 'SSH',
        'target': true,
      }],
      'portType': 'TCP',
      'portNumber': 22,
    },
    {
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'services': [{
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'portType': 'TCP',
        'serviceName': 'HTTP',
      }],
      'portType': 'TCP',
      'portNumber': 443,
    },
    {
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'services': [{
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'portType': 'TCP',
        'serviceName': 'HTTP',
      }],
      'portType': 'TCP',
      'portNumber': 80,
    }],
    'createDate': 1498470178000,
    'updateDate': 1498470178000,
  },
  {
    'firstScanRange': 1,
    'lastScanRange': 10000,
    'name': '',
    'ip': 3232235781,
    'mac': 91754660625,
    'os': 'Windows',
    'ports': [{
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'services': [{
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'portType': 'TCP',
        'serviceName': 'SSH',
      }],
      'portType': 'TCP',
      'portNumber': 22,
    },
    {
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'services': [{
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'portType': 'TCP',
        'serviceName': 'HTTP',
      }],
      'portType': 'TCP',
      'portNumber': 80,
    },
    {
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'services': [{
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'portType': 'TCP',
        'serviceName': 'HTTP',
      }],
      'portType': 'TCP',
      'portNumber': 1936,
    },
    {
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'services': null,
      'portType': 'TCP',
      'portNumber': 443,
    }],
    'createDate': 1498470178000,
    'updateDate': 1498470178000,
  },
  {
    'firstScanRange': 1,
    'lastScanRange': 10000,
    'name': '',
    'ip': 3232235797,
    'mac': 91754662913,
    'os': 'Windows',
    'target': true,
    'ports': [{
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'services': [{
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'portType': 'TCP',
        'serviceName': 'HTTP',
      }],
      'portType': 'TCP',
      'portNumber': 80,
    },
    {
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'services': [{
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'portType': 'TCP',
        'serviceName': 'SSH',
      }],
      'portType': 'TCP',
      'portNumber': 22,
    },
    {
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'services': [{
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'portType': 'TCP',
        'serviceName': 'HTTP',
      }],
      'portType': 'TCP',
      'portNumber': 3343,
    },
    {
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'services': [{
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'portType': 'TCP',
        'serviceName': 'HTTP',
      }],
      'portType': 'TCP',
      'portNumber': 443,
    }],
    'createDate': 1498470178000,
    'updateDate': 1498470178000,
  },
  {
    'firstScanRange': 1,
    'lastScanRange': 10000,
    'name': '',
    'ip': 3232235877,
    'mac': 75361038758387,
    'os': 'Windows',
    'ports': null,
    'createDate': 1498470179000,
    'updateDate': 1498470179000,
  },


];


const hostListJsonMini: any = [
  {
    'firstScanRange': 1,
    'lastScanRange': 10000,
    'name': '',
    'ip': 3232235797,
    'mac': 91754662913,
    'os': 'Windows',
    'target': true,
    'ports': [
      {
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'services': [{
          'createDate': -62135596800000,
          'updateDate': -62135596800000,
          'portType': 'TCP',
          'serviceName': 'HTTP',
        }],
        'portType': 'TCP',
        'portNumber': 3343,
      },
      {
        'createDate': -62135596800000,
        'updateDate': -62135596800000,
        'services': [{
          'createDate': -62135596800000,
          'updateDate': -62135596800000,
          'portType': 'TCP',
          'serviceName': 'HTTP',
        }],
        'portType': 'TCP',
        'portNumber': 443,
      }],
    'createDate': 1498470178000,
    'updateDate': 1498470178000,
  },


];


const hostListJsonMini2: any = [{
  'firstScanRange': 1,
  'lastScanRange': 10000,
  'name': '',
  'ip': 3232235781,
  'mac': 91754660625,
  'os': 'Windows',
  'ports': [{
    'createDate': -62135596800000,
    'updateDate': -62135596800000,
    'services': [{
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'portType': 'TCP',
      'serviceName': 'SSH',
    }],
    'portType': 'TCP',
    'portNumber': 22,
  },
  {
    'createDate': -62135596800000,
    'updateDate': -62135596800000,
    'services': [{
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'portType': 'TCP',
      'serviceName': 'HTTP',
    }],
    'portType': 'TCP',
    'portNumber': 80,
  },
  {
    'createDate': -62135596800000,
    'updateDate': -62135596800000,
    'services': [{
      'createDate': -62135596800000,
      'updateDate': -62135596800000,
      'portType': 'TCP',
      'serviceName': 'HTTP',
    }],
    'portType': 'TCP',
    'portNumber': 1936,
  },
  {
    'createDate': -62135596800000,
    'updateDate': -62135596800000,
    'services': null,
    'portType': 'TCP',
    'portNumber': 443,
  }],
  'createDate': 1498470178000,
  'updateDate': 1498470178000,
},
];
