import Action from '@overflow/commons/redux/Action';
import EmailAuth from '@overflow/email/api/model/EmailAuth';

import ReadByAuthKeyPayload from '../payload/ReadByAuthKeyPayload';

// Action Type
export type REQUEST = '@overflow/email/read_by_auth_key/REQUEST';
export type REQUEST_SUCCESS = '@overflow/email/read_by_auth_key/REQUEST_SUCCESS';
export type REQUEST_FAILURE = '@overflow/email/read_by_auth_key/REQUEST_FAILURE';

export const REQUEST: REQUEST = '@overflow/email/read_by_auth_key/REQUEST';
export const REQUEST_SUCCESS: REQUEST_SUCCESS = '@overflow/email/read_by_auth_key/REQUEST_SUCCESS';
export const REQUEST_FAILURE: REQUEST_FAILURE = '@overflow/email/read_by_auth_key/REQUEST_FAILURE';

// Action Creater
export type request = (authKey: string) => Action<ReadByAuthKeyPayload>;
export type requestSuccess = (emailAuth: EmailAuth) => Action<EmailAuth>;
export type requestFailure = (error: Error) => Action;

export const request: request = (authKey: string): Action<ReadByAuthKeyPayload> => {
  return {
    type: REQUEST,
    payload: {
      authKey: authKey,
    },
  };
};

export const requestSuccess: requestSuccess = (emailAuth: EmailAuth): Action<EmailAuth> => {
  return {
    type: REQUEST_SUCCESS,
    payload: emailAuth,
  };
};

export const requestFailure: requestFailure = (error: Error): Action => {
  return {
    type: REQUEST_FAILURE,
    error: error,
  };
};
