import *as React from 'react';
import Member from '../../api/model/Member';

import {
  InputOnChangeData,
  Button,
  Form,
  ButtonProps,
} from 'semantic-ui-react';
import MemberStatus from '../../api/model/MemberStatus';

export interface StateProps {
  member?:Member;
}

export interface DispatchProps {
  onSignUp?(member: Member): void;
  onRedirectHome():void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  email: string;
  name: string;
  pass: string;
  passCon: string;
  company: string;
  phone: string;
  country: string;
}

const options = [
  { key: 'southkorea', value: '82', text: 'South Korea(82)' },
  { key: 'unitedstates', value: '1', text: 'United States(1)' },
];


export class SignUp extends React.Component<Props, State> {
  constructor(props?: Props, context?: State) {
    super(props, context);

    this.state = {
      email: null,
      name: null,
      pass: null,
      passCon: null,
      company: null,
      phone: null,
      country: null,
    };

  }

  public onChange (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData):void {
    console.log(event);
    console.log(data);
  }

  public render(): JSX.Element {

    let signupElement = <Form>
      <Form.Input fluid value={this.state.email} placeholder='Email' onChange={
        (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData) => {
          this.setState({ email: data.value });
        }} />
      <Form.Input fluid placeholder='Name' onChange= {
        (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData) => {
          this.setState({ name: data.value });
        }
      }/>
      <Form.Input fluid placeholder='Password' type='password' onChange={
        (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData) => {
          this.setState({ pass: data.value });
        }
      } />
      <Form.Input fluid placeholder='Password Confirm' type='password' onChange={
        (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData) => {
          this.setState({ passCon: data.value });
        }
      } />
      <Form.Input fluid placeholder='Company' onChange={
        (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData) => {
          this.setState({ company: data.value });
        }
      }/>
      <Form.Select fluid value={this.state.country} placeholder='Select your country' options={options} onChange={
        (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData) => {
          this.setState({ country: data.value });
        }
      } />
      <Form.Input fluid placeholder='phone' onChange={
        (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData) => {
          this.setState({ phone: data.value });
        }
      } />
      <Form.Group>
        <Button primary fluid style={{margin:'7'}} onClick={this.signUpClick}>   Sign Up  </Button>
        <Button fluid style={{margin:'7'}}>    Cancel  </Button>
      </Form.Group>
    </Form>;
    if (this.props.member !== undefined && this.props.member.id > 0) {
      // Todo Please check the member registration e-mail.
      this.props.onRedirectHome();
    } else {
      return signupElement;
    }

  }

  private signUpClick = (event: React.SyntheticEvent<HTMLButtonElement>, data: ButtonProps):void => {

    let member:Member = {};
    member.pw = this.state.pass;

    if (member.pw !== this.state.passCon) {
      return;
    }

    member.email = this.state.email;
    member.name = this.state.name;
    member.companyName = this.state.company;
    member.phone = this.state.phone;
    // member.status = MemberStatus.NOAUTH;

    this.props.onSignUp(member);
  }

}

