
import * as React from 'react';
import { Icon, Step, Button, Table, Radio, Form, Container, Checkbox } from 'semantic-ui-react';
import { Grid, Image, Label, Segment, Dropdown, Input, List, Accordion, Loader } from 'semantic-ui-react';

import MetaCrawler from '@overflow/meta/api/model/MetaCrawler';
import MetaCrawlerInputItem from '@overflow/meta/api/model/MetaCrawlerInputItem';

import SensorItemTree from '@overflow/meta/react/SensorItemTree';

export interface CrawlerAuthInputsStateProps {
  crawlerId?: number;
  crawler?: MetaCrawler;
  metaCrawlerInputItemList?: MetaCrawlerInputItem[];
}

export interface CrawlerAuthInputsDispatchProps {
}

export type CrawlerAuthInputsProps = CrawlerAuthInputsStateProps & CrawlerAuthInputsDispatchProps;



export interface CrawlerAuthInputsState {
  isVerifying: boolean;
}

export class CrawlerAuthInputs extends React.Component<CrawlerAuthInputsProps, CrawlerAuthInputsState> {

  // private data: object[];
  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      isVerifying: false,
    };

  }

  public componentWillMount(): void {
    // this.data = [
    //   {
    //     'id': '1',
    //     'metaInputType': {
    //       'id': '1',
    //       'name': 'Text',
    //     },
    //     'name': 'Community',
    //     'required': 'true',
    //     'defaultValue': 'public',
    //     'keyName': 'Community',
    //     'keyValue': '',
    //     'pattern': 'regex...',
    //   },
    //   {
    //     'id': '2',
    //     'metaInputType': {
    //       'id': '2',
    //       'name': 'Radio',
    //     },
    //     'name': 'AuthType',
    //     'required': 'true',
    //     'defaultValue': '',
    //     'keyName': 'AuthType',
    //     'keyValue': 'MD5|SHA',
    //     'pattern': 'regex...',
    //   },
    // ];
  }

  public handleVerify(): void {
    this.setState({
      isVerifying: true,
    });
  }

  public renderRow(item: MetaCrawlerInputItem, index: number): JSX.Element {
    let elem = new Array();
    if (item.inputType.name === 'TEXT_TYPE') {
      elem.push(<Input placeholder={item.defaultValue} key={0} />);
    } else if (item.inputType.name === 'PASSWORD_TYPE') {
      elem.push(<Input type='password' placeholder={item.defaultValue} key={0} />);
    } else if (item.inputType.name === 'Radio') {
      let itemValues = item.keyValue.split('|');
      let idx = 0;
      for (let itemValue of itemValues) {
        elem.push(<Form.Radio
          key={idx++}
          label={itemValue}
          name='radioGroup'
          value={itemValue}
        />);
      }
    }

    return (
      <Table.Row key={index}>
        <Table.Cell collapsing>{item.keyName}</Table.Cell>
        <Table.Cell >
          <Form.Group inline>{elem}</Form.Group>
        </Table.Cell>
      </Table.Row >
    );
  }

  public renderAuth(): JSX.Element[] {

    if (this.props.metaCrawlerInputItemList === undefined) {
      return null;
    }

    let elements: Array<JSX.Element> = new Array();
    let elem: JSX.Element;
    for (let index: number = 0; index < this.props.metaCrawlerInputItemList.length; ++index) {
      elem = this.renderRow(this.props.metaCrawlerInputItemList[index], index);
      elements.push(elem);
    }

    return elements;
  }

  public render(): JSX.Element {
    // if (this.props.crawlerId === null) {
    //   return null;
    // }
    // this.props.onCrawlerReadAllByMetaCrawler(this.props.crawler);

    if (this.props.metaCrawlerInputItemList === undefined || this.props.metaCrawlerInputItemList.length <= 0) {
      return null;
    }


    return (
      <Segment style={{ width: '350px' }}>
        <Table basic='very' celled >
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell colSpan='2'>{this.props.crawler} 접속 정보</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.renderAuth()}
          </Table.Body>

          <Table.Footer>
            <Table.Row>
              <Table.HeaderCell colSpan='2'>
                <Button primary floated={'right'} onClick={this.handleVerify.bind(this)} loading={this.state.isVerifying}>Verify</Button>
              </Table.HeaderCell>
            </Table.Row>
          </Table.Footer>
        </Table>
      </Segment>
    );
  }
}
