import { connect, Dispatch } from 'react-redux';
import {
  NoauthProbeList,
  StateProps as NoAuthProbeListStateProps,
  DispatchProps as NoAuthProbeListDispatchProps,
} from './components/NoauthProbeList';
import Domain from '@overflow/domain/api/model/Domain';
import * as asyncRequestActions from '@overflow/commons/redux/action/asyncRequest';
import * as noauthListActions from '../redux/action/read_all_by_domain';
import * as denyActions from '../redux/action/deny';
import * as acceptActions from '../redux/action/accept';
import NoAuthProbe from '@overflow/noauthprobe/api/model/NoAuthProbe';

export function mapStateToProps(state: any): NoAuthProbeListStateProps {
  return {
    noauthList: state.noauthList,
  };
}

export function mapDispatchToProps(dispatch: Dispatch<any>): NoAuthProbeListDispatchProps {
  return {
    onReadAllByDomain: (domain: Domain) => {
      dispatch(asyncRequestActions.request('NoAuthProbeService', 'readAllByDomain', noauthListActions.REQUEST, JSON.stringify(domain)));
    },
    acceptNoAuthProbe: (noauthProbes: NoAuthProbe[]) => {
      dispatch(
        asyncRequestActions.request(
          'NoAuthProbeService', 'acceptNoAuthProbes', acceptActions.REQUEST, JSON.stringify(noauthProbes)));
    },
    denyNoAuthProbe: (noauthProbes: NoAuthProbe[]) => {
      dispatch(
        asyncRequestActions.request(
          'NoAuthProbeService', 'denyNoauthProbes', denyActions.REQUEST, JSON.stringify(noauthProbes)));
    },
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(NoauthProbeList);
