import * as React from 'react';
import {
  Table,
  Checkbox,
  Button,
  Header,
  Container,
  Modal,
  Icon,
  List,
} from 'semantic-ui-react';
import NoAuthProbe from '@overflow/noauthprobe/api/model/NoAuthProbe';
import Domain from '@overflow/domain/api/model/Domain';
import { ListContainer } from '@overflow/commons/react/component/ListContainer';
import * as Utils from '@overflow/commons/util/Utils';
export interface StateProps {
  noauthList?: NoAuthProbe[];
}

export interface DispatchProps {
  onReadAllByDomain?(domain: Domain): void;
  acceptNoAuthProbe?(noauthProbe: NoAuthProbe[]): void;
  denyNoAuthProbe?(noauthProbe: NoAuthProbe[]): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: NoAuthProbe[];
  modalVisible: boolean;
  actionDisabled: boolean;
  isDeny: boolean;
}

export class NoauthProbeList extends React.Component<Props, State> {

  private data: any;
  private selectedIds: NoAuthProbe[];

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      selected: [],
      modalVisible: false,
      actionDisabled: true,
      isDeny: false,
    };
    this.selectedIds = new Array();
  }

  public componentWillMount(): void {
    let domain: Domain = {
      id: 1,
    };
    this.props.onReadAllByDomain(domain);
  }

  public handleSelect(probe: NoAuthProbe): void {
    let idx = this.selectedIds.indexOf(probe);
    if (idx === -1) {
      this.selectedIds.push(probe);
    } else {
      this.selectedIds.splice(idx, 1);
    }
    this.setState({
      selected: this.selectedIds,
    });
  }

  // tslint:disable-next-line:no-empty
  public handleSearch = (result: any[]): void => {
  }

  public checkExist(probe: NoAuthProbe): boolean {
    if (this.state.selected.indexOf(probe) === -1) {
      return false;
    }
    return true;
  }

  public handleActionDisable(): boolean {
    if (this.state.selected === null || this.state.selected === undefined) {
      return true;
    }
    if (this.state.selected.length === 0) {
      return true;
    }
    return false;
  }

  public handleConfirm(): void {
    if (this.state.isDeny) {
      console.log('Denied.');
      this.props.denyNoAuthProbe(this.state.selected);
    } else {
      console.log('Accepted.');
      this.props.acceptNoAuthProbe(this.state.selected);
    }
    this.setState({
      modalVisible: false,
    });
  }

  public handleDeny(): void {
    this.setState({
      isDeny: true,
      modalVisible: true,
    });
  }

  public handleRowActive(probe: NoAuthProbe): boolean {
    if (this.state.selected.indexOf(probe) === -1) {
      return false;
    }
    return true;
  }
  public showList(): JSX.Element[] {
    return this.state.selected.map((probe: NoAuthProbe, index: number) => (
      <div key={index}>
        {probe.ipAddress}
      </div>
    ));
  }

  public render(): JSX.Element {
    let noauth =
      <Container fluid>
        <Table celled selectable striped>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell />
              <Table.HeaderCell textAlign={'center'}>No.</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Host IP</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Host Mac</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Host Name</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Created At</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>API Key</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.renderRows()}
          </Table.Body>
        </Table>
        {/* <Button primary disabled={this.state.actionDisabled} */}
        <Button primary disabled={this.handleActionDisable()}
          floated={'right'} onClick={() => this.setState({ modalVisible: true, isDeny: false })}>
          Accept
        </Button>
        <Button disabled={this.handleActionDisable()} floated={'right'}
          onClick={() => this.setState({ modalVisible: true, isDeny: true })}>
          Deny
        </Button>

        <Modal size='tiny'
          open={this.state.modalVisible}
        >
          <Header icon='certificate' content='Confirm' />
          <Modal.Content>
            Are you sure?
              {this.showList()}
          </Modal.Content>
          <Modal.Actions>
            <Button color='red' onClick={() => this.setState({ modalVisible: false })}>
              <Icon name='remove' /> No
            </Button>
            <Button color='green' onClick={this.handleConfirm.bind(this)} >
              <Icon name='checkmark' /> Yes
            </Button>
          </Modal.Actions>
        </Modal>
      </Container>;
    return (
      <ListContainer
        contents={noauth}
        data={this.props.noauthList}
        onSearch={this.handleSearch}
        filter={null}
      />
    );
  }

  private renderRows(): (JSX.Element | JSX.Element[]) {
    if (this.props.noauthList === undefined) {
      return null;
    }

    if (this.props.noauthList.length === 0) {
      return <Table.Row error >
        <Table.Cell textAlign='center' colSpan='6'>No results found.</Table.Cell>
      </Table.Row>;
    }

    return this.props.noauthList.map((probe: NoAuthProbe, index: number) => (
      <Table.Row key={index} onClick={this.handleSelect.bind(this, probe)} active={this.handleRowActive(probe)}>
        <Table.Cell collapsing>
          <Checkbox checked={this.checkExist(probe)} />
        </Table.Cell>
        <Table.Cell textAlign={'center'}>{index + 1}</Table.Cell>
        <Table.Cell textAlign={'center'}>{probe.ipAddress}</Table.Cell>
        <Table.Cell textAlign={'center'}>{probe.macAddress}</Table.Cell>
        <Table.Cell>{probe.hostName}</Table.Cell>
        <Table.Cell textAlign={'center'}>{Utils.date2date(probe.createDate)}</Table.Cell>
        <Table.Cell textAlign={'center'}>{probe.apiKey}</Table.Cell>
      </Table.Row>
    ));
  }
}

