import { connect, Dispatch } from 'react-redux';
import {
    ProbeDetailInfo,
    StateProps as ProbeDetailStateProps,
    DispatchProps as ProbeDetailDispatchProps,
} from './components/ProbeDetailInfo';
import { push as routerPush } from 'react-router-redux';
import Probe from '@overflow/probe/api/model/Probe';
import * as asyncRequestActions from '@overflow/commons/redux/action/asyncRequest';
import * as probeReadActions from '../redux/action/read';
import * as probeModifyActions from '../redux/action/modify';

export function mapStateToProps(state: any, props: any): ProbeDetailStateProps {
    return {
        id: props.params.id,
        probe: state.probe,
    };
}

export function mapDispatchToProps(dispatch: Dispatch<any>): ProbeDetailDispatchProps {
    return {
        onRead: (id: string) => {
            dispatch(asyncRequestActions.request('ProbeService', 'read', probeReadActions.REQUEST, id));
        },
        onDiscoveryClick: (id: string) => {
            dispatch(routerPush(id + '/ targets'));
        },
        onModify: (probe: Probe) => {
            dispatch(asyncRequestActions.request('ProbeService', 'modify', probeModifyActions.REQUEST, JSON.stringify(probe)));
        },
    };
}

export default connect(mapStateToProps, mapDispatchToProps)(ProbeDetailInfo);

