import * as React from 'react';
import {
  Button,
  Table,
  Label,
  Segment,
  Header,
  Container,
  Input,
  InputOnChangeData,
  Icon,
} from 'semantic-ui-react';
import Probe from '@overflow/probe/api/model/Probe';
import { Discovery } from '@overflow/discovery/react/components/Discovery';

import * as Utils from '@overflow/commons/util/Utils';

export interface StateProps {
  id?: string;
  probe?: Probe;
}

export interface DispatchProps {
  onRead?(id: string): void;
  onDiscoveryClick?(id: string): void;
  onModify?(probe: Probe): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  name: string;
  desc: string;
  nameModifying: boolean;
  descModifying: boolean;
}


export class ProbeDetailInfo extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      name: undefined,
      desc: undefined,
      nameModifying: false,
      descModifying: false,
    };
    this.props.onRead(this.props.id);
  }

  public componentWillMount(): void {
    console.log('');
  }

  public handleStartStop(event: any, data: any): void {
    console.log(event);
  }

  public handleDiscovery = (event: any, data: any): void => {
    this.props.onDiscoveryClick(this.props.id);
  }


  public showStopBtn(): JSX.Element {
    if (this.props.probe.status.name === 'NORMAL') {
      return <Button content='Stop' icon='stop' labelPosition='left' negative />;
    }
  }

  public handleNameModify = () => {
    const p: Probe = this.props.probe;
    p.displayName = this.state.name;
    this.props.onModify(p);
    this.setState({
      nameModifying: false,
    });
  }

  public handleDescModify = () => {
    let p: Probe = this.props.probe;
    p.description = this.state.desc;
    this.props.onModify(p);
    this.setState({
      descModifying: false,
    });
  }


  public render(): JSX.Element {
    if (this.props.probe === undefined) {
      return null;
    }
    return (
      <Container fluid>
        {this.renderDetail()}
        {this.showStopBtn()}
        <Button content='Discovery' icon='search' labelPosition='left' floated={'right'} positive onClick={this.handleDiscovery} />
        {/*{this.renderDiscovery()}*/}
      </Container>
    );
  }

  public renderDisplayName(): JSX.Element {
    if (this.state.nameModifying) {
      return (
        <Input action={{ color: 'teal', icon: 'save', onClick: this.handleNameModify.bind(this) }}
          defaultValue={this.props.probe.displayName} size='small' onChange={
            (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData) => {
              this.setState({ name: data.value });
            }} />
      );
    } else {
      return (
        <div>
          {this.props.probe.displayName}
          <Button icon circular size='mini'
            onClick={() => this.setState({ name: this.props.probe.displayName, nameModifying: true })}>
            <Icon name='edit' />
          </Button>
        </div>
      );
    }
  }

  public renderDescription(): JSX.Element {
    if (this.state.descModifying) {
      return (
        <Input fluid action={{ color: 'teal', icon: 'save', onClick: this.handleDescModify.bind(this) }}
          defaultValue={this.props.probe.description} size='small' onChange={
            (event: React.SyntheticEvent<HTMLInputElement>, data: InputOnChangeData) => {
              this.setState({ desc: data.value });
            }} />
      );
    } else {
      return (
        <div>
          {this.props.probe.description}
          <Button icon circular size='mini'
            onClick={() => this.setState({ desc: this.props.probe.description, descModifying: true })}>
            <Icon name='edit' />
          </Button>
        </div>
      );
    }
  }

  private renderDetail(): JSX.Element {
    if (this.props.probe === undefined) {
      return null;
    }
    return (
      <Table celled={false} >
        <Table.Body>
          <Table.Row>
            <Table.Cell collapsing>
              <Header size='small'>Name</Header>
            </Table.Cell>
            <Table.Cell>
              {this.renderDisplayName()}
            </Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              <Header size='small'>Status</Header>
            </Table.Cell>
            <Table.Cell>{this.props.probe.status.name}</Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              <Header size='small'>Created at</Header>
            </Table.Cell>
            <Table.Cell>{Utils.date2date(this.props.probe.createDate)}</Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              <Header size='small'>Authorized at</Header>
            </Table.Cell>
            <Table.Cell>{Utils.date2date(this.props.probe.authorizeDate)}</Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              <Header size='small'>Authorized by</Header>
            </Table.Cell>
            <Table.Cell>{this.props.probe.authorizeMember.name}</Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              <Header size='small'>Uptime</Header>
            </Table.Cell>
            <Table.Cell>todo.</Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              <Header size='small'>Description</Header>
            </Table.Cell>
            <Table.Cell>
              {this.renderDescription()}
            </Table.Cell>
          </Table.Row>
        </Table.Body>
      </Table>
    );
  }

}

