import * as React from 'react';
import {
  Button,
  Table,
  Label,
  Segment,
  Header,
  Container,
} from 'semantic-ui-react';
import Probe from '@overflow/probe/api/model/Probe';
import ProbeHostModel from '@overflow/probe/api/model/ProbeHost';
import InfraHost from '@overflow/infra/api/model/InfraHost';

import * as Utils from '@overflow/commons/util/Utils';

export interface StateProps {
  id: string;
  probe: Probe;
  probeHost: ProbeHostModel;
}

export interface DispatchProps {
  onRead?(id: string): void;
  onHostReadByProbe?(probe: Probe): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
}


export class ProbeHost extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      host: null,
    };
  }

  public componentWillMount(): void {
    // this.props.onRead(this.props.id);
    this.props.onHostReadByProbe({id: Number(this.props.id)});
  }


  public render(): JSX.Element {

    if(this.props.probeHost === undefined) {
      return null;
    }

    return (
      <Container fluid>
        <Table celled={false}>
          <Table.Body>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>IP</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probeHost.host ? Utils.int2ip(this.props.probeHost.host.ip) : ''}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>MAC</Header>
              </Table.Cell>
              <Table.Cell>{Utils.intToMac(this.props.probeHost.host.mac)}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>OS meta</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probeHost.host.os.meta}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>OS vendor name</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probeHost.host.os.vendor.name}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>OS vendor type</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probeHost.host.os.vendor.infraType.name}</Table.Cell>
            </Table.Row>
          </Table.Body>
        </Table>
      </Container>
    );
  }
}

