import * as React from 'react';
import { Table, Header, Container, Form, Checkbox, Button } from 'semantic-ui-react';
import { ListContainer } from '@overflow/commons/react/component/ListContainer';
import Probe from '@overflow/probe/api/model/Probe';
import Domain from '@overflow/domain/api/model/Domain';

export interface StateProps {
  probeList?: Probe[];
}

export interface DispatchProps {
  onReadAllByDomain?(domain: Domain): void;
  onProbeSelection?(id: string): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: Probe;
}

export class ProbeList extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);

    this.state = {
      selected: null,
    };
  }

  public componentWillMount(): void {
    let domain: Domain = {
      id: 1,
    };
    this.props.onReadAllByDomain(domain);
  }

  public checkCellStatus(status: any): boolean {
    if (status.name === 'STOPPED') {
      return true;
    }
    return false;
  }

  public handleSelect(selectedProbe: any): void {
    this.setState({
      selected: selectedProbe,
    });

    this.props.onProbeSelection(selectedProbe.id);
  }

  public handleSearch = (result: Probe[]): void => {
    // this.setState({
    //   list: result,
    // });
  }

  public handleFilter(filterStr: string): void {
    // if (filterStr === null) {
    //   this.setState({
    //     list: this.props.probeList,
    //   });
    //   return;
    // }
    // let founds = new Array();
    // for (let probe of this.props.probeList) {
    //   if (probe.status.name.indexOf(filterStr) !== -1) {
    //     founds.push(probe);
    //   }
    // }
    // this.setState({
    //   list: founds,
    // });
  }

  public render(): JSX.Element {
    let probeList =
      <Container fluid>
        <Table selectable striped celled>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>Name</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>CIDR</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>IP</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Status</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Target Count</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Sensor Count</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.renderRows()}
          </Table.Body>
        </Table>
      </Container>;

    return (
      <ListContainer
        contents={probeList}
        data={this.props.probeList}
        onSearch={this.handleSearch}
        filter={<ProbeFilter onFilter={this.handleFilter.bind(this)} />}
      />
    );
  }

  private renderRows(): (JSX.Element | JSX.Element[]) {
    if (this.props.probeList === undefined) {
      return null;
    }
    if (this.props.probeList.length === 0) {
      return <Table.Row error >
        <Table.Cell textAlign='center' colSpan='6'>No results found.</Table.Cell>
      </Table.Row>;
    }
    return this.props.probeList.map((probe: Probe, index: number) => (
      <Table.Row key={index} onClick={this.handleSelect.bind(this, probe)}>
        <Table.Cell >{probe.displayName}</Table.Cell>
        <Table.Cell>{probe.cidr}</Table.Cell>
        <Table.Cell>todo</Table.Cell>
        <Table.Cell negative={this.checkCellStatus(probe.status)} textAlign={'center'}>{probe.status.name}</Table.Cell>
        <Table.Cell textAlign={'center'} >{probe.targetCount}</Table.Cell>
        <Table.Cell textAlign={'center'} >{probe.sensorCount}</Table.Cell>
      </Table.Row>
    ));
  }
}

export class ProbeFilter extends React.Component<any, any> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      status: null,
    };
  }

  public handleChange(e: any, data: any): void {
    this.setState({
      status: data.value,
    });
    this.props.onFilter(data.value);
  }
  public handleReset(e: any, data: any): void {
    this.setState({
      status: null,
    });
    this.props.onFilter(null);
  }

  public render(): JSX.Element {
    // todo. getting MetaProbeStatus
    let metaProbeStatus = [
      {
        'id': '1',
        'name': 'INITIAL',
      },
      {
        'id': '2',
        'name': 'NORMAL',
      },
    ];
    return (
      <Form>
        <Container fluid>
          <Button size='mini' floated='right' basic content='Reset' onClick={this.handleReset.bind(this)} />
          <Form.Field>
            <b>Status</b>
          </Form.Field>

          {metaProbeStatus.map((item: any, index: number) => (
            <Form.Field key={index}>
              <Checkbox
                radio
                label={item.name}
                name='status'
                value={item.name}
                checked={this.state.status === item.name}
                onChange={this.handleChange.bind(this)}
              />
            </Form.Field>
          ))}
        </Container>
      </Form>
    );
  }
}



