import Action from '@overflow/commons/redux/Action';
import Probe from '../../api/model/Probe';
import ReadByProbeKeyPayload from '../payload/ReadByProbeKeyPayload';
import Domain from '@overflow/domain/api/model/Domain';

// Action Type
export type REQUEST = '@overflow/probe/read_by_probekey/REQUEST';
export type REQUEST_SUCCESS = '@overflow/probe/read_by_probekey/REQUEST_SUCCESS';
export type REQUEST_FAILURE = '@overflow/probe/read_by_probekey/REQUEST_FAILURE';

export const REQUEST: REQUEST = '@overflow/probe/read_by_probekey/REQUEST';
export const REQUEST_SUCCESS: REQUEST_SUCCESS = '@overflow/probe/read_by_probekey/REQUEST_SUCCESS';
export const REQUEST_FAILURE: REQUEST_FAILURE = '@overflow/probe/read_by_probekey/REQUEST_FAILURE';

// Action Creater
export type request = (probeKey: string) => Action<ReadByProbeKeyPayload>;
export type requestSuccess = (probe: Probe) => Action<Probe>;
export type requestFailure = (error: Error) => Action;



export const request: request = (probeKey: string): Action<ReadByProbeKeyPayload> => {
  return {
    type: REQUEST,
    payload: {
      probeKey: probeKey,
    },
  };
};

export const requestSuccess: requestSuccess = (probe: Probe): Action<Probe> => {
  return {
    type: REQUEST_SUCCESS,
    payload: probe,
  };
};

export const requestFailure: requestFailure = (error: Error): Action => {
  return {
    type: REQUEST_FAILURE,
    error: error,
  };
};
