import { connect, Dispatch } from 'react-redux';
import { push as routerPush } from 'react-router-redux';

import {
  SensorList,
  StateProps as SensorListStateProps,
  DispatchProps as SensorListDispatchProps,
} from './components/SensorList';
import State from '../redux/state/ReadAllByTarget';


import * as ReadAllByTargetActions from '../redux/action/read_all_by_target';
import * as ReadAllByProbeActions from '../redux/action/read_all_by_probe';
import * as ReadAllByDomainActions from '../redux/action/read_all_by_domain';
import Target from '@overflow/target/api/model/Target';
import Sensor from '@overflow/sensor/api/model/Sensor';
import Probe from '@overflow/probe/api/model/Probe';
import Domain from '@overflow/domain/api/model/Domain';

import * as asyncRequestActions from '@overflow/commons/redux/action/asyncRequest';

export function mapStateToProps(state: any): SensorListStateProps {
  return {
    sensorList:state.SensorList,
  };
}

export function mapDispatchToProps(dispatch: Dispatch<any>): SensorListDispatchProps {
  return {
    onReadAllByTarget: (target: Target) => {
      dispatch(asyncRequestActions.request('SensorService', 'readAllByTarget', ReadAllByTargetActions.REQUEST, JSON.stringify(target)));
    },
    onReadAllByProbe: (probe: Probe) => {
      dispatch(ReadAllByProbeActions.request(probe));
    },
    onReadAllByDomain: (domain: Domain) => {
       dispatch(asyncRequestActions.request('SensorService', 'readAllByDomain', ReadAllByDomainActions.REQUEST, JSON.stringify(domain)));
    },
    onSelectSensor: (id: number) => {
      dispatch(routerPush('/sensor/' + String(id)));
    },
    onAddSensor: (target: Target) => {
      dispatch(routerPush('/sensor/setup'));
    },
  };
}


export default connect(mapStateToProps, mapDispatchToProps)(SensorList);
