import * as React from 'react';
import { Table, Button, Header, Container } from 'semantic-ui-react';
import { ListContainer } from '@overflow/commons/react/component/ListContainer';

import Probe from '@overflow/probe/api/model/Probe';
import Sensor from '@overflow/sensor/api/model/Sensor';
import Target from '@overflow/target/api/model/Target';
import Domain from '@overflow/domain/api/model/Domain';

export interface StateProps {
  probe?: Probe;
  target?: Target;
  sensorList?: Sensor[];
  targetId?: number;
}

export interface DispatchProps {
  onReadAllByTarget?(target: Target): void;
  onReadAllByProbe?(probe: Probe): void;
  onReadAllByDomain?(domain: Domain): void;
  onSelectSensor?(id: number): void;
  onAddSensor?(target: Target): void;
}

export type SensorListProps = StateProps & DispatchProps;

export interface SensorListState {
  selected: Sensor;
}


export class SensorList extends React.Component<SensorListProps, SensorListState> {

  // private data: any;

  constructor(props: SensorListProps, context: SensorListState) {
    super(props, context);
    this.state = {
      selected: null,
    };
  }

  public componentWillMount(): void {
    // super.componentWillMount();
    if (this.props.targetId === undefined) {
      let domain: Domain = {
        id: 1,
      };
      this.props.onReadAllByDomain(domain);
    } else {
      let target: Target = {
        id: this.props.targetId,
      };
      this.props.onReadAllByTarget(target);
    }

  }

  public handleSelect(selectedSensor: Sensor): void {
    this.setState({
      selected: selectedSensor,
    });

    this.props.onSelectSensor(selectedSensor.id);
  }

  public checkCellStatus(status: any): boolean {
    if (status.name === 'STOPPED') {
      return true;
    }
    return false;
  }

  public showStartStopBtn(status: any): JSX.Element {
    if (status.name === 'STARTED') {
      return <Button content='Stop' icon='stop' labelPosition='left' color={'blue'} floated={'right'} onClick={this.handleStartStop} />;
    } else {
      return <Button content='Start' icon='play' labelPosition='left' color={'blue'} floated={'right'} onClick={this.handleStartStop} />;
    }
  }

  public handleStartStop(event: any, data: any): void {
    console.log(event);
  }
  public handleAddSensor(): void {
    this.props.onAddSensor(this.props.target);
  }

  public render(): JSX.Element {

    let sensorList: JSX.Element = (
      <Container fluid>
        <Table celled selectable striped>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>No.</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Status</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Crawler</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Description</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Item count</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.props.sensorList ? this.props.sensorList.map((sensor: Sensor, index: number) => (
              <Table.Row key={index} onClick={this.handleSelect.bind(this, sensor)}>
                <Table.Cell textAlign={'center'}>{index + 1}</Table.Cell>
                <Table.Cell negative={this.checkCellStatus(sensor.status)} textAlign={'center'}>
                  {sensor.status.name}
                </Table.Cell>
                <Table.Cell><Header size='small'>{sensor.crawler.name}</Header></Table.Cell>
                <Table.Cell>{sensor.description}</Table.Cell>
                <Table.Cell>to do</Table.Cell>
                {/* <Table.Cell collapsing>{this.showStartStopBtn(sensor.metaSensorStatus)}</Table.Cell> */}
              </Table.Row>
            )) : ''}
          </Table.Body>
        </Table>
        <Button content='Add' icon='add' labelPosition='left' floated='right' positive onClick={this.handleAddSensor.bind(this)} />

      </Container>
    );

    return (
      <ListContainer
        contents={sensorList}
        data={this.props.sensorList}
      />
    );

  }

}



