import { connect, Dispatch } from 'react-redux';
import {
  TargetList,
  StateProps as StateProps,
  DispatchProps as DispatchProps,
} from './components/TargetList';

import Probe from '@overflow/probe/api/model/Probe';
import Domain from '@overflow/domain/api/model/Domain';
import * as targetListActions from '../redux/action/read_all_by_probe';
import { push as routerPush } from 'react-router-redux';
import * as asyncRequestActions from '@overflow/commons/redux/action/asyncRequest';

export function mapStateToProps(state: any, props: any): StateProps {
  return {
    probeId: props.params.id,
    infraList: state.infraList,
  };
}

export function mapDispatchToProps(dispatch: Dispatch<any>): DispatchProps {
  return {
    onReadAllByProbe: (probe: Probe) => {
       dispatch(asyncRequestActions.request('InfraService', 'readAllByProbe', targetListActions.REQUEST, JSON.stringify(probe)));
    },
    onReadAllByDomain: (domain: Domain) => {
       dispatch(asyncRequestActions.request('InfraService', 'readAllByDomain', targetListActions.REQUEST, JSON.stringify(domain)));
    },
    onTargetSelection: (id: string) => {
      dispatch(routerPush('/target/' + id));
    },
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(TargetList);
