import * as _ from 'lodash';
import * as React from 'react';
import { Table } from 'semantic-ui-react';


export interface StateProps {
  jsonObj:any;
}

export interface DispatchProps {
  onBodyRowClick?(row:any):void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  column: string;
  data: any;
  direction: 'ascending' | 'descending';
}

//
// const tableData = [
//   { 'name': 'John', 'age': 15, 'gender': 'Male' },
//   { 'name': 'Amber', 'age': 40, 'gender': 'Female' },
//   { 'name': 'Leslie', 'age': 25, 'gender': 'Female' },
//   { 'name': 'Ben', 'age': 70, 'gender': 'Male' },
// ];

const tableData = [
  {
    'id': '11',

    'cidr': '192.168.1.0/24',
    'displayName': '192.168.1.105\'s probe',
    // 'infraHost': {
    //   'ip': '192.168.1.105',
    //   'mac': 'ab:cd:ef:gh:ij',
    // },
    'targetCount': '20',
    'sensorCount': '30',
    'probeKey': '1AGBLKDFJ2452ASDGFL2KWJLKSDJ',
    'description': 'description1111111111',
  },
  {
    'id': '22',
    'displayName': '192.168.1.102\'s probe',
    'cidr': '192.168.1.0/24',
    'targetCount': '20',
    'sensorCount': '50',
    'probeKey': '1AGBLKDFJ2452ASDGFL2KWJLKSDJ',
    'description': 'description1111111111',
  },
  {
    'id': '33',
    'cidr': '192.168.1.0/24',
    'displayName': '192.168.1.101\'s probe',
    'targetCount': '20',
    'sensorCount': '60',
    'probeKey': '1AGBLKDFJ2452ASDGFL2KWJLKSDJ',
    'description': 'description1111111111',
  },
];

export class TableSort extends React.Component<Props, State> {
  constructor(props: Props, context: State) {
    super(props, context);

    this.state = {
      column: null,
      data: tableData,
      direction:  null,
    };
  }

  public render(): JSX.Element  {
    return (
      <Table sortable celled fixed>
        <Table.Header>
          {this.generationHeaderRow()}
        </Table.Header>
        <Table.Body>
          {this.generationBodyRow()}
        </Table.Body>
      </Table>
    );
  }

  private getHeaderValue = ():Map<string, string> => {
    let tem:any = this.state.data;
    let column:Map<string, string> = new Map();
    for (let obj in tem) {
      if (tem.hasOwnProperty(obj)) {
        Object.keys(tem[obj]).map((key:string ) => {
          if (tem[obj].hasOwnProperty(key)) {
            if (column.get(key) != null ) {
              return column;
            }
            column.set(key, key);
          }
        });
      }
    }

    return column;
  }

  private generationHeaderRow(): (JSX.Element | JSX.Element[]) {
    return (

      <Table.Row>
        {
          this.renderHeaderCells()
        }

      </Table.Row>
    );
  }

  private renderHeaderCells = ():JSX.Element[] => {
    const { column, data, direction } = this.state;
    let te = this.getHeaderValue();
    let arr = [];
    te.forEach((value:string, key:string ) => {

      arr.push(
        <Table.HeaderCell
          sorted={column === value ? direction : 'ascending'}
          onClick={this.handleSort(value)} >{value}</Table.HeaderCell> );
    });

    return arr;
  }

  private generationBodyRow(): JSX.Element[] {
    let arr = [];
    let idx:number = 0;
    for(let temp of this.state.data) {
      arr.push( <Table.Row key={idx++}> { this.renderBodyCells(temp) } </Table.Row> );
    }
    return arr;
  }

  private renderBodyCells = (temp:any): JSX.Element[] => {
    let te = this.getHeaderValue();
    let arr = [];

    te.forEach((value:string, key:string ) => {

      arr.push(<Table.Cell>{temp[key]}</Table.Cell>);
    });
    return arr;
  }


  private handleSort = (clickedColumn:string) => ():void => {
    const {column, data, direction} = this.state;

    if (column !== clickedColumn) {
      this.setState({
        column: clickedColumn,
        data: _.sortBy(data, [clickedColumn]),
        direction: 'ascending',
      });

      return;
    }

    this.setState({
      data: data.reverse(),
      direction: direction === 'ascending' ? 'descending' : 'ascending',
    });
  }
}

